@@ -14,28 +14,83 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.2';    # VERSION
+our $VERSION = '3.3';    # VERSION
 my @OPTIONS_ATTRIBUTES
     = qw/format short repeatable negativable autosplit doc/;
 
+# todo to support multiple role
+# { package $target; sub _option_information { shift->maybe::next::method(@_) } }
+
 sub import {
     my ( undef, @import ) = @_;
-    my %import_options
-        = ( protect_argv => 1, flavour => [], skip_options => [], @import );
-    my %skip_options;
-    if ( defined $import_options{skip_options} ) {
-        %skip_options
-            = map { ( $_ => 1 ) } @{ $import_options{skip_options} };
-    }
+    my $import_options
+        = { protect_argv => 1, flavour => [], skip_options => [], @import };
 
     my $target = caller;
     my $with   = $target->can('with');
     my $around = $target->can('around');
+    my $has    = $target->can('has');
 
-    $with->('MooX::Options::Role');
-
-    my $_options_meta = {};
+    my $options_meta = {};
     my $modifier_done;
+    my $apply_modifiers = sub {
+        return if $modifier_done;
+        $with->('MooX::Options::Role');
+
+        ## no critic qw/ProhibitStringyEval/
+        unless (
+            eval '
+        package ' . $target . ';
+
+        sub _options_meta {
+            my ( $class, @meta ) = @_;
+            return $class->maybe::next::method(@meta);
+        }
+
+        sub _options_params {
+            my ( $class, @params ) = @_;
+            return $class->maybe::next::method(@params);
+        }
+        '
+            )
+        {
+            croak $@ if $@;
+        }
+        ## use critic
+
+        $around->(
+            _options_meta => sub {
+                my ( $orig, $self ) = ( shift, shift );
+                return ( $self->$orig(@_), %$options_meta );
+            }
+        );
+
+        $around->(
+            _options_params => sub {
+                my ( $orig, $self ) = ( shift, shift );
+                return $self->$orig(@_), %$import_options;
+
+                #for debug purpose
+                #my @p = $self->$orig(@_);
+                #my @q = %$import_options;
+                #use Carp;
+                #use Data::Dumper;
+                #carp "p:",Dumper \@p;
+                #carp "q:",Dumper \@q;
+                #return @p,@q;
+            }
+        );
+
+        #if ( my $info = $Role::Tiny::INFO{$target} ) {
+        #    for my $sref (qw/meta params/) {
+        #        my $meth = $target->can('_options_' . $sref);
+        #        $info->{not_methods}{$meth} = $meth;
+        #    }
+        #}
+
+        $modifier_done = 1;
+    };
+
     my $option = sub {
         my ( $name, %attributes ) = @_;
         for my $ban (
@@ -47,30 +102,19 @@ sub import {
                 if $name eq $ban;
         }
 
-        $target->can('has')->( $name => _filter_attributes(%attributes) );
+        $has->( $name => _filter_attributes(%attributes) );
 
-        if ( !$skip_options{$name} ) {
-            $_options_meta->{$name}
-                = { _validate_and_filter_options(%attributes) };
-        }
+        $options_meta->{$name}
+            = { _validate_and_filter_options(%attributes) };
 
-        unless ($modifier_done) {
-            $around->(
-                _options_meta => sub {
-                    my ( $orig, $self ) = ( shift, shift );
-                    return ( $self->$orig(@_), %$_options_meta );
-                }
-            );
-            $around->(
-                _options_params => sub {
-                    my ( $orig, $self ) = ( shift, shift );
-                    return ( $self->$orig(@_), %import_options );
-                }
-            );
-            $modifier_done = 1;
-        }
+        $apply_modifiers->();
         return;
     };
+
+    if ( my $info = $Role::Tiny::INFO{$target} ) {
+        $info->{not_methods}{$option} = $option;
+    }
+
     { no strict 'refs'; *{"${target}::option"} = $option; }
 
     return;
@@ -93,8 +137,8 @@ sub _validate_and_filter_options {
     $cmdline_options{repeatable} = 1 if $cmdline_options{autosplit};
     $cmdline_options{format} .= "@"
         if $cmdline_options{repeatable}
-        && defined $cmdline_options{format}
-        && substr( $cmdline_options{format}, -1 ) ne '@';
+            && defined $cmdline_options{format}
+            && substr( $cmdline_options{format}, -1 ) ne '@';
 
     croak
         "Negativable params is not usable with non boolean value, don't pass format to use it !"
@@ -113,7 +157,7 @@ MooX::Options - add option keywords to your object (Mo/Moo/Moose)
 
 =head1 VERSION
 
-version 3.2
+version 3.3
 
 =head1 MooX::Options
 
@@ -435,4 +479,3 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 __END__
-
