@@ -12,7 +12,7 @@ package MooX::Options::Role;
 use strict;
 use warnings;
 
-our $VERSION = '3.2';    # VERSION
+our $VERSION = '3.3';    # VERSION
 
 use MRO::Compat;
 use Moo::Role;
@@ -31,6 +31,12 @@ sub parse_options {
     my ( $class, %params ) = @_;
     my %metas          = $class->_options_meta;
     my %options_params = $class->_options_params;
+    my @skip_options;
+    @skip_options = @{ $options_params{skip_options} }
+        if defined $options_params{skip_options};
+    if (@skip_options) {
+        delete @metas{@skip_options};
+    }
     my @options;
 
     my $option_name = sub {
@@ -97,7 +103,9 @@ sub parse_options {
     for my $name ( keys %metas ) {
         my %meta = %{ $metas{$name} };
         if ( !defined $cmdline_params{$name} ) {
-            $cmdline_params{$name} = $opt->$name();
+            if ( defined( my $val = $opt->$name() ) ) {
+                $cmdline_params{$name} = $val;
+            }
         }
         push @missing_required, $name
             if $meta{required} && !defined $cmdline_params{$name};
@@ -114,16 +122,6 @@ sub parse_options {
 }
 ## use critic
 
-sub _options_meta {
-    my ( $class, @meta ) = @_;
-    return $class->maybe::next::method(@meta);
-}
-
-sub _options_params {
-    my ( $class, @params ) = @_;
-    return $class->maybe::next::method(@params);
-}
-
 sub options_usage {
     my ( $self, $code, @messages ) = @_;
     $code = 0 if !defined $code;
@@ -135,6 +133,7 @@ sub options_usage {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -143,7 +142,7 @@ MooX::Options::Role - role that is apply to your object
 
 =head1 VERSION
 
-version 3.2
+version 3.3
 
 =head1 METHODS
 
@@ -190,4 +189,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
